=======
Contact
=======

QEpy Developers
================

Feel free to contact the developers:
 - `Xuecheng Shao <https://sites.rutgers.edu/prg/people/xuecheng-shao/>`_
 - `Michele Pavanello <https://sasn.rutgers.edu/about-us/faculty-staff/michele-pavanello>`_

On-line
=======

To find out more about the `Pavanello Research Group <http://sites.rutgers.edu/prg>`_. Or simply send us an email.

GitLab
======

Feel free to create new issues, merge requests or fork your own `QEpy` on our gitlab page: https://gitlab.com/shaoxc/qepy

Make sure to let us know about your developments!

References
==========

.. dropdown:: QEpy
    :open:

    .. literalinclude:: QEpy.bib
        :lines: 1-7

.. dropdown:: Quantum ESPRESSO

    .. literalinclude:: QEpy.bib
        :lines: 9-25

.. dropdown:: f90wrap

    .. literalinclude:: QEpy.bib
        :lines: 27-39
